@@ -12,6 +12,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of the diurnal range is written
 #'  (character).
@@ -56,10 +58,11 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_dayrange.nc")))
-dayrange <- function(var, infile, outfile, nc34=4, overwrite = FALSE, verbose = FALSE) {
+dayrange <- function(var, infile, outfile, nc34=4, overwrite = FALSE, verbose = FALSE,
+                     nc = NULL) {
   check_variable(var)
 
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
 
   outfile <- correct_filename(outfile)
@@ -70,7 +73,7 @@ dayrange <- function(var, infile, outfile, nc34=4, overwrite = FALSE, verbose =
   calc_time_start <- Sys.time()
 
   # get information about dimensions and attributes
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
   file_data$variable$prec <- "float"
 
   # extract time information
@@ -145,7 +148,8 @@ dayrange <- function(var, infile, outfile, nc34=4, overwrite = FALSE, verbose =
   )
 
   dummy <- array(NA, dim = c(length(file_data$dimension_data$x), length(file_data$dimension_data$y), 1))
-  nc_in <- nc_open(infile)
+  if (!is.null(nc)) nc_in <- nc
+  else nc_in <- nc_open(infile)
   nc_out <- nc_open(outfile, write = TRUE)
 
   count <- 1
@@ -170,7 +174,7 @@ dayrange <- function(var, infile, outfile, nc34=4, overwrite = FALSE, verbose =
               count = c(-1, 1))
     count <- count + 1
   }
-  nc_close(nc_in)
+  if (is.null(nc)) nc_close(nc_in)
   nc_close(nc_out)
 
   calc_time_end <- Sys.time()
