@@ -15,6 +15,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file excluding the selected time period is written.
 #'@export
@@ -60,10 +62,10 @@
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_extract.period.nc")))
 extract.period <- function(var, start, end, infile, outfile, nc34 = 4,
-                           overwrite = FALSE, verbose = FALSE) {
+                           overwrite = FALSE, verbose = FALSE, nc = NULL) {
   check_variable(var)
 
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
 
   outfile <- correct_filename(outfile)
@@ -81,9 +83,9 @@ extract.period <- function(var, start, end, infile, outfile, nc34 = 4,
   calc_time_start <- Sys.time()
 
   # get information about dimensions and attributes
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
   if (file_data$time_info$has_time_bnds) {
-    time_bnds <- get_time_bounds_from_file(infile)
+    time_bnds <- get_time_bounds_from_file(infile, nc = nc)
   }
 
   # extract time information
@@ -153,7 +155,8 @@ extract.period <- function(var, start, end, infile, outfile, nc34 = 4,
   )
 
   # extract desired times from infile
-  nc_in <- nc_open(infile)
+  if (!is.null(nc)) nc_in <- nc
+  else nc_in <- nc_open(infile)
   nc_out <- nc_open(outfile, write = TRUE)
   limit <-
     2601 * 2601 * 31  # This value can be ajusted to avoid RAM overflow
@@ -252,7 +255,7 @@ extract.period <- function(var, start, end, infile, outfile, nc34 = 4,
   #   }
   # }
 
-  nc_close(nc_in)
+  if (is.null(nc)) nc_close(nc_in)
   nc_close(nc_out)
 
   calc_time_end <- Sys.time()
