@@ -13,6 +13,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of differences is written.
 #'@export
@@ -56,18 +58,19 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_mon.anomaly.nc")))
-mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
+mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE,
+                        nc = NULL) {
   calc_time_start <- Sys.time()
 
   check_variable(var)
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
   outfile <- correct_filename(outfile)
   check_overwrite(outfile, overwrite)
   check_nc_version(nc34)
 
   ##### extract data from file #####
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
   file_data$variable$prec <- "float"
   months_all <- get_date_time(file_data$dimension_data$t, file_data$time_info$units)$months
   years_all <- get_date_time(file_data$dimension_data$t, file_data$time_info$units)$year
@@ -76,7 +79,7 @@ mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbo
 
   ### calculate monthly means
   monmean_file <- tempfile(pattern = "monmean", tmpdir = tempdir(), fileext = ".nc")
-  monmean(var = file_data$variable$name, infile = infile, outfile = monmean_file, nc34 = nc34, overwrite = TRUE, verbose = verbose)
+  monmean(var = file_data$variable$name, infile = infile, outfile = monmean_file, nc34 = nc34, overwrite = TRUE, verbose = verbose, nc = nc)
   nc_monmean <- nc_open(monmean_file)
   monmeans <- ncvar_get(nc_monmean, file_data$variable$name)
   monmeans_months_all <- get_date_time(ncvar_get(nc_monmean, "time"), ncatt_get(nc_monmean, "time", "units")$value)$months
@@ -117,7 +120,7 @@ mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbo
 
     vars_data <- list(result = data_placeholder, time_bounds = time_bnds)
 
-  clim <- get_climatology(infile, file_data)
+  clim <- get_climatology(infile, file_data, nc = nc)
 
   nc_format <- get_nc_version(nc34)
   cmsaf_info <- paste0("cmsaf::mon.anomaly for variable ",
@@ -163,7 +166,8 @@ mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbo
     monmean_dummy <- which(monmeans_months_all == months_unique[j])
     startt <- dummy_vec[mon_dummy]
 
-    nc_in <- nc_open(infile)
+    if (!is.null(nc)) nc_in <- nc
+    else nc_in <- nc_open(infile)
 
     dum_dat <- array(NA, dim = c(length(file_data$dimension_data$x), length(file_data$dimension_data$y), length(startt)))
 
@@ -171,7 +175,7 @@ mon.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbo
        dum_dat[, , i] <- ncvar_get(nc_in, file_data$variable$name, start = c(1, 1, startt[i]), count = c(-1, -1, 1), collapse_degen = FALSE)
     }
 
-    nc_close(nc_in)
+    if (is.null(nc)) nc_close(nc_in)
 
     if (verbose) message(paste0("apply monthly anomaly ", j,
                                 " of ", length(months_unique)))
