@@ -1,15 +1,16 @@
-monx_wrapper <- function(op, var, infile, outfile, nc34, overwrite, verbose, p = NULL) {
+monx_wrapper <- function(op, var, infile, outfile, nc34, overwrite, verbose, p = NULL,
+                         nc = NULL) {
   calc_time_start <- Sys.time()
 
   check_variable(var)
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
   outfile <- correct_filename(outfile)
   check_overwrite(outfile, overwrite)
   check_nc_version(nc34)
 
   ##### extract data from file #####
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
 
   if (op > 2) {
     file_data$variable$prec <- "float"
@@ -117,7 +118,8 @@ monx_wrapper <- function(op, var, infile, outfile, nc34, overwrite, verbose, p =
     startt <- min(dummy_vec[mon_dummy])
     countt <- length(mon_dummy)
 
-    nc_in <- nc_open(infile)
+    if (!is.null(nc)) nc_in <- nc
+    else nc_in <- nc_open(infile)
     dum_dat <- ncvar_get(nc_in, file_data$variable$name, start = c(1, 1, startt), count = c(-1, -1, countt), collapse_degen = FALSE)
 
     switch(op,
@@ -159,7 +161,7 @@ monx_wrapper <- function(op, var, infile, outfile, nc34, overwrite, verbose, p =
     ncvar_put(nc_out, vars[[1]], data, start = c(1, 1, count), count = c(-1, -1, 1))
     count <- count + 1
 
-    nc_close(nc_in)
+    if (is.null(nc)) nc_close(nc_in)
   }
 
   nc_close(nc_out)
