@@ -14,6 +14,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including the selected time period is written.
 #'
@@ -62,22 +64,22 @@
 selperiod <- local({
   count <- 1
   function(var, start, end, infile, outfile, nc34 = 4,
-                        overwrite = FALSE, verbose = FALSE) {
+                        overwrite = FALSE, verbose = FALSE, nc = NULL) {
     count <<- 1
     calc_time_start <- Sys.time()
     gc()
     check_variable(var)
-    check_infile(infile)
+    if (is.null(nc)) check_infile(infile)
     check_outfile(outfile)
     outfile <- correct_filename(outfile)
     check_overwrite(outfile, overwrite)
     check_nc_version(nc34)
     
     # get information about dimensions and attributes
-    file_data <- read_file(infile, var)
+    file_data <- read_file(infile, var, nc = nc)
     file_data$variable$prec <- "float"
     if (file_data$time_info$has_time_bnds) {
-      time_bnds <- get_time_bounds_from_file(infile)
+      time_bnds <- get_time_bounds_from_file(infile, nc = nc)
     }
   
     # extract time information
@@ -141,7 +143,8 @@ selperiod <- local({
     )
   
     # extract desired times from infile
-    nc_in <- nc_open(infile)
+    if (!is.null(nc)) nc_in <- nc
+    else nc_in <- nc_open(infile)
     nc_out <- nc_open(outfile, write = TRUE)
   
     # dum_dat <- ncvar_get(nc_in, file_data$variable$name, start  = c(1, 1, date_in[1]), count = c(-1, -1, length(date_in)))
@@ -167,7 +170,7 @@ selperiod <- local({
       }
     }
   
-    nc_close(nc_in)
+    if (is.null(nc)) nc_close(nc_in)
     nc_close(nc_out)
   
     calc_time_end <- Sys.time()
