@@ -13,6 +13,8 @@
 #'  will be in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of area weighted spatial means
 #'  is written.
@@ -57,6 +59,7 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_wfldmean.nc")))
-wfldmean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  fldx_wrapper(4, var, infile, outfile, nc34, overwrite, verbose)
+wfldmean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE,
+                     nc = NULL) {
+  fldx_wrapper(4, var, infile, outfile, nc34, overwrite, verbose, nc = nc)
 }
