@@ -12,6 +12,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of multi-year daily means is
 #'  written.
@@ -56,18 +58,19 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_ydaymean.nc")))
-ydaymean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
+ydaymean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE,
+                     nc = NULL) {
   calc_time_start <- Sys.time()
 
   check_variable(var)
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
   outfile <- correct_filename(outfile)
   check_overwrite(outfile, overwrite)
   check_nc_version(nc34)
 
   ##### extract data from file #####
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
   file_data$variable$prec <- "float"
   date.time <- as.Date(get_time(file_data$time_info$units, file_data$dimension_data$t))
   dateID <- getDateID(date.time)
@@ -131,7 +134,8 @@ ydaymean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose
               length(file_data$dimension_data$y),
               length(startt))
     )
-    nc_in <- nc_open(infile)
+    if (!is.null(nc)) nc_in <- nc
+    else nc_in <- nc_open(infile)
     for (i in seq_along(startt)) {
       dum_dat[, , i] <- ncvar_get(
         nc_in,
@@ -141,7 +145,7 @@ ydaymean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose
         collapse_degen = FALSE
       )
     }
-    nc_close(nc_in)
+    if (is.null(nc)) nc_close(nc_in)
 
     if (verbose) message(paste0("averaging day ", j))
 
