@@ -12,6 +12,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of annual anomalies is written.
 #'@export
@@ -55,18 +57,19 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_year.anomaly.nc")))
-year.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
+year.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE,
+                         nc = NULL) {
   calc_time_start <- Sys.time()
 
   check_variable(var)
-  check_infile(infile)
+  if (is.null(nc)) check_infile(infile)
   check_outfile(outfile)
   outfile <- correct_filename(outfile)
   check_overwrite(outfile, overwrite)
   check_nc_version(nc34)
 
   ##### extract data from file #####
-  file_data <- read_file(infile, var)
+  file_data <- read_file(infile, var, nc = nc)
   file_data$variable$prec <- "float"
   years_all <- get_date_time(file_data$dimension_data$t, file_data$time_info$units)$years
   years_unique <- sort(unique(years_all))
@@ -84,7 +87,7 @@ year.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verb
   )
   vars_data <- list(result = data_placeholder, time_bounds = time_bnds)
 
-  clim <- get_climatology(infile, file_data)
+  clim <- get_climatology(infile, file_data, nc = nc)
 
   nc_format <- get_nc_version(nc34)
   cmsaf_info <- paste0("cmsaf::year.anomaly for variable ",
@@ -128,7 +131,8 @@ year.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verb
     year_dummy <- which(years_all == years_unique[j])
     startt <- min(dummy_vec[year_dummy])
     countt <- length(year_dummy)
-    nc_in <- nc_open(infile)
+    if (!is.null(nc)) nc_in <- nc
+    else nc_in <- nc_open(infile)
 
     dum_dat <- ncvar_get(
       nc_in,
@@ -137,7 +141,7 @@ year.anomaly <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verb
       count = c(-1, -1, countt),
       collapse_degen = FALSE
     )
-    nc_close(nc_in)
+    if (is.null(nc)) nc_close(nc_in)
 
     if (verbose) message(paste0("apply yearly anomaly ", j,
                    " of ", length(years_unique)))
